@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Meltytech, LLC
+ * Copyright (c) 2012-2019 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,10 +36,11 @@
 #include <QFileInfo>
 #include <QStorageInfo>
 #include <QProcess>
+#include <QRegularExpression>
 
 // formulas to map absolute value ranges to percentages as int
-#define TO_ABSOLUTE(min, max, rel) qRound(float(min) + float((max) - (min) + 1) * float(rel) / 100.0f)
-#define TO_RELATIVE(min, max, abs) qRound(100.0f * float((abs) - (min)) / float((max) - (min) + 1))
+#define TO_ABSOLUTE(min, max, rel) qRound(float(min) + float((max) - (min)) * float(rel) / 100.0f)
+#define TO_RELATIVE(min, max, abs) qRound(100.0f * float((abs) - (min)) / float((max) - (min)))
 static const int kOpenCaptureFileDelayMs = 1500;
 static const qint64 kFreeSpaceThesholdGB = 50LL * 1024 * 1024 * 1024;
 static const int kCustomPresetFileNameRole = Qt::UserRole + 1;
@@ -803,7 +804,7 @@ Mlt::Properties* EncodeDock::collectProperties(int realtime)
                     p->set("frame_rate_num", 60000);
                     p->set("frame_rate_den", 1001);
                 } else {
-                    // Workaround storing QDoubleSpinBox::value() loses precison.
+                    // Workaround storing QDoubleSpinBox::value() loses precision.
                     p->set("frame_rate_num", qRound(ui->fpsSpinner->value() * 1000000.0));
                     p->set("frame_rate_den", 1000000);
                 }
@@ -993,7 +994,7 @@ void EncodeDock::enqueueMelt(const QString& target, int realtime)
         if (MAIN.playlist() && MAIN.playlist()->count() > 1) {
             QFileInfo fi(target);
             int n = MAIN.playlist()->count();
-            int digits = QString::number(n + 1).size();
+            int digits = QString::number(n).size();
             for (int i = 0; i < n; i++) {
                 QScopedPointer<Mlt::ClipInfo> info(MAIN.playlist()->clip_info(i));
                 if (!info) continue;
@@ -1204,10 +1205,16 @@ void EncodeDock::on_encodeButton_clicked()
         }
 #endif
     }
+
     QString caption = seekable? tr("Export File") : tr("Capture File");
+    QString nameFilter;
+    if (!m_extension.isEmpty())
+        nameFilter = tr("%1 (*.%2);;All Files (*)").arg(ui->formatCombo->currentText()).arg(m_extension);
+    else
+        tr("Determined by Export (*)");
     m_outputFilename = QFileDialog::getSaveFileName(this,
         caption, directory,
-        QString(), 0, QFileDialog::HideNameFilterDetails);
+        nameFilter, 0, QFileDialog::HideNameFilterDetails);
     if (!m_outputFilename.isEmpty()) {
         QFileInfo fi(m_outputFilename);
         MLT.pause();
@@ -1731,16 +1738,33 @@ void EncodeDock::on_hwencodeCheckBox_clicked(bool checked)
         QStringList hwlist;
         QFileInfo ffmpegPath(qApp->applicationDirPath(), "ffmpeg");
         foreach (const QString& codec, codecs()) {
-            LOG_DEBUG() << "checking for" << codec;
-            QCoreApplication::processEvents();
+            LOG_INFO() << "checking for" << codec;
             QProcess proc;
+            QStringList args;
+            args << "-hide_banner" << "-f" << "lavfi" << "-i" << "color=s=640x360" << "-t" << "0.040" << "-an";
+            if (codec.endsWith("_vaapi"))
+                args << "-vaapi_device" << ":0" << "-vf" << "format=nv12,hwupload";
+            else if (codec == "hevc_qsv")
+                args << "-load_plugin" << "hevc_hw";
+            args << "-c:v" << codec << "-f" << "rawvideo" << "pipe:";
+            LOG_DEBUG() << ffmpegPath.absoluteFilePath() << args;
             proc.setStandardOutputFile(QProcess::nullDevice());
-            proc.start(QString::fromLatin1("%1 -f lavfi -i color=s=640x360 -t 0.040 -an %2 -c:v %3 -f rawvideo pipe:")
-                       .arg(ffmpegPath.absoluteFilePath())
-                       .arg(codec.endsWith("_vaapi")? "-vaapi_device :0 -vf format=nv12,hwupload" : "")
-                       .arg(codec));
-            if (proc.waitForFinished(5000) && proc.exitStatus() == QProcess::NormalExit && !proc.exitCode())
+            proc.setReadChannel(QProcess::StandardError);
+            proc.start(ffmpegPath.absoluteFilePath(), args, QIODevice::ReadOnly);
+            bool started = proc.waitForStarted(2000);
+            bool finished = false;
+            QCoreApplication::processEvents();
+            if (started) {
+                finished = proc.waitForFinished(4000);
+                QCoreApplication::processEvents();
+            }
+            if (started && finished && proc.exitStatus() == QProcess::NormalExit && !proc.exitCode()) {
                 hwlist << codec;
+            } else {
+                QString output = proc.readAll();
+                foreach (const QString& line, output.split(QRegularExpression("[\r\n]"), QString::SkipEmptyParts))
+                    LOG_DEBUG() << line;
+            }
         }
         if (hwlist.isEmpty()) {
             MAIN.showStatusMessage(tr("Nothing found"), 10);
